@@ -26,7 +26,9 @@
 
 #include "error.h"
 
-struct nxt_t;
+#define NXT_CONNECTION_SIZE sizeof("usb.255.255")
+#define NXT_SERIAL_SIZE sizeof("00:16:53:01:02:03")
+
 typedef struct nxt_t nxt_t;
 
 typedef enum
@@ -37,8 +39,15 @@ typedef enum
   N_FIRMWARES,
 } nxt_firmware;
 
+typedef void (*nxt_list_cb_t)(void *user, const char *connection,
+                              nxt_firmware fw, const char *serial,
+                              const char *name);
+
 nxt_error_t nxt_init(nxt_t **nxt);
-nxt_error_t nxt_find(nxt_t *nxt);
+void nxt_exit(nxt_t *nxt);
+nxt_error_t nxt_list(nxt_t *nxt, nxt_list_cb_t cb, void *user);
+nxt_error_t nxt_find(nxt_t *nxt, nxt_firmware match_fw,
+                     const char *match_serial, const char *match_name);
 nxt_error_t nxt_open(nxt_t *nxt);
 void nxt_close(nxt_t *nxt);
 int nxt_is_firmware(nxt_t *nxt, nxt_firmware fw);
